/*-----------------------------------------------------------------------*/
/* UPCO - ICAI      Departamento de Electronica y automatica             */
/*-----------------------------------------------------------------------*/
/*                                                                       */
/* Prototipos biblioteca dic.h: diccionario de palabras                  */
/*                                                                       */
/* Descripcion: funciones para gestion de un diccionario de palabras de  */
/*              tamao limitado.                                         */
/* El diccionario esta organizado como un vector de tamao fijo cuyos    */
/* elementos son punteros a las cadenas de caracteres que definen cada   */
/* palabra. Dichas cadenas son de tamao ajustado a la longitud de la    */
/* palabra. El diccionario esta definido por dos variables:              */
/*                                                                       */
/*          char **ppsDic: vector de punteros a las palabras.            */
/*          int nPal: numero de palabras en el diccionario.              */
/*                                                                       */
/* Autor: Jose Antonio Rodriguez Mondejar                                */
/* Fecha: 1/9/98                                                         */
/* Versin: 1.0                                                          */
/*                                                                       */
/*-----------------------------------------------------------------------*/


#ifndef dic_h
#define dic_h

#define MAXDIC 500   /* define el numero maximo de palabras */

#include <stdio.h>

/*FUNCIONES DE MENU DEL DICCIONARIO*/

/*-----------------------------------------------------------------------*/
/* void MenuCargaDicFic(char **ppsDic,int *pnPal,int max)                */
/*      CARGA EL DICCIONARIO DE PALABRAS DESDE UN FICHERO                */
/*                                                                       */
/* Descripcion: Pide el fichero desde donde se carga el diccionario y lo */
/*              carga en el vector de palabras ppsDic. Si el fichero es  */
/*              de mayor capacidad que la del diccionario, solo se lee   */
/*              lo permitido y se genera un mensaje de error. Las        */
/*              palabras pueden no estar en la misma linea.              */
/*                                                                       */
/* Argumentos: char **ppsDic: el diccionario (vector de palabras)        */
/*             int *pnPal: numero de palabras cargadas                   */
/*             int max: numero maximo de palabras admitidas              */
/*                                                                       */
/* Devuelve: *ppsDic y *pnPal actualizados                               */
/*                                                                       */
/*-----------------------------------------------------------------------*/

void MenuCargaDicFic(char **ppsDic,int *pnPal,int max);

/*-----------------------------------------------------------------------*/
/* void MenuSalvaDic(char **ppsDic,int nPal)                             */
/*      GUARDA EL DICCIONARIO DE PALABRAS EN UN FICHERO                  */
/*                                                                       */
/* Descripcion: Si existe el diccionario y no esta vacio, se pide el     */
/*              nombre del fichero donde se va a guardar y se salva.     */
/*                                                                       */
/* Argumentos: char **ppsDic: el diccionario (vector de palabras)        */
/*             int nPal: numero de palabras en diccionario               */
/*                                                                       */
/* Devuelve: fichero conteniendo el diccionario                          */
/*                                                                       */
/*-----------------------------------------------------------------------*/

void MenuSalvaDic(char **ppsDic,int nPal);

/*FUNCIONES DE GESTION DEL DICCIONARIO*/


/*-----------------------------------------------------------------------*/
/* int CargaDicFic(int *pnPal,FILE *pfic,char **ppsDic,int max)          */
/*      CARGA EL DICCIONARIO DE PALABRAS DESDE UN FICHERO                */
/*                                                                       */
/* Descripcion: Cargar un fichero en el diccionario. El diccionario debe */
/*              existir y estar vacio. Si el fichero es de mayor         */
/*              capacidad que la del diccionario, solo se lee            */
/*              lo permitido y se genera un mensaje de error. Las        */
/*              palabras pueden no estar en la misma linea.              */
/*                                                                       */
/* Argumentos: int *pnPal: numero de palabras cargado                    */
/*             FILE *pfic: fichero correcto en modo lectura              */
/*             char **ppsDic: el diccionario (vector de palabras)        */
/*             int max: maximo numero de palabras admitidas              */                                              
/*                                                                       */
/* Devuelve: **ppsDic actualizado con la lectura                         */
/*           int numero de palabras leidas                               */
/*                                                                       */
/*-----------------------------------------------------------------------*/

int CargaDicFic(int *pnPal,FILE *pfic,char **ppsDic,int max);

/*-----------------------------------------------------------------------*/
/* int ImpDic(char **ppsDic,int nPal)                                    */
/*      MUESTRA EL DICCIONARIO DE PALABRAS POR PANTALLA                  */
/*                                                                       */
/* Descripcion: El diccionario debe existir y no estar vacio.            */
/*              Las palabras se muestran en diferentes lineas            */
/*                                                                       */
/* Argumentos: char **ppsDic: el diccionario (vector de palabras)        */
/*             int nPal: numero de palabras en el diccionario            */                                              
/*                                                                       */
/* Devuelve: palabras del diccionario por pantalla                       */
/*                                                                       */
/*-----------------------------------------------------------------------*/

void ImpDic(char **ppsDic, int nPal);

/*-----------------------------------------------------------------------*/
/* void OrdenaDic(char **ppsDic,int nPal)                                */
/*      ORDENA EL DICCIONARIO DE PALABRAS                                */
/*                                                                       */
/* Descripcion: Ordena las palabras del diccionario por orden alfabetico */
/*                                                                       */
/* Argumentos: char **ppsDic: el diccionario (vector de palabras)        */
/*             int nPal: numero de palabras en el diccionario            */                                              
/*                                                                       */
/* Devuelve: el diccionario actualizado (ordenado)                       */
/*                                                                       */
/*-----------------------------------------------------------------------*/

void OrdenaDic(char **ppsDic,int nPal);

/*-----------------------------------------------------------------------*/
/* void SalvaDic(FILE *pfic,char **ppsDic,int nPal)                      */
/*      GUARDA TODAS LAS PALABRAS                                        */
/*                                                                       */
/* Descripcion: El diccionario debe existir y no estar vacio.            */
/*              Las palabras se van escribiendo en el fichero en         */
/*              diferentes lineas. El fichero debe estar preparado para  */
/*              escribir en el.                                          */
/*                                                                       */
/* Argumentos: char **ppsDic: el diccionario (vector de palabras)        */
/*             int *pnPal: numero de palabras cargadas                   */                                              
/*                                                                       */
/* Devuelve: el fichero actualizado                                      */
/*                                                                       */
/*-----------------------------------------------------------------------*/

void SalvaDic(FILE *pfic,char **ppsDic, int nPal);

/*-----------------------------------------------------------------------*/
/* void BorraDic(char **ppsDic,int *pnPal)                               */
/*      BORRA TODAS LAS PALABRAS                                         */
/*                                                                       */
/* Descripcion: Borra todas las palabras del diccionario y deja los      */
/*              los elementos del vector de punteros apuntando a NULL    */
/*                                                                       */
/* Argumentos: char **ppsDic: el diccionario (vector de palabras)        */
/*             int *pnPal: numero de palabras cargadas                   */                                              
/*                                                                       */
/* Devuelve: el diccionario actualizado                                  */
/*           nPal actualizado                                            */
/*                                                                       */
/*-----------------------------------------------------------------------*/

void BorraDic(char **ppsDic,int *pnPal);

/*-----------------------------------------------------------------------*/
/* void MenuBorraPal(char **ppsDic,int *pnPal)                           */
/*      BORRA LA PALABRA ELEGIDA                                         */
/*                                                                       */
/* Descripcion: Pide la palabra a borrar, la busca en el diccionario, si */
/*              la encuentra la borra, dejando la entrada a NULL y       */
/*              reajustando el diccionario. Si no la encuentra, da un    */
/*              mensaje indicandolo.                                     */
/*                                                                       */
/* Argumentos: char **ppsDic: el diccionario (vector de palabras)        */
/*             int *pnPal: numero de palabras cargadas                   */                                              
/*                                                                       */
/* Devuelve: el diccionario actualizado                                  */
/*           nPal actualizado                                            */
/*                                                                       */
/*-----------------------------------------------------------------------*/

void MenuBorraPal(char **ppsDic,int *pnPal);

/*-----------------------------------------------------------------------*/
/* int BuscaPal(char **ppsDic,int nPal)                                  */
/*      BUSCA LA PALABRA ELEGIDA                                         */
/*                                                                       */
/* Descripcion: Pide la palabra a buscar, si la encuentra devuelve su    */
/*              posicion.                                                */
/*                                                                       */
/* Argumentos: char **ppsDic: el diccionario (vector de palabras)        */
/*             int nPal: numero de palabras cargadas                     */                                              
/*                                                                       */
/* Devuelve: la posicion donde ha encontrado la palabra. En caso de no   */
/*           encontrarla, devuelve las palabras cargadas                 */
/*                                                                       */
/*-----------------------------------------------------------------------*/

int BuscaPal (char **ppsDic,int nPal);

/*-----------------------------------------------------------------------*/
/* void AjustaDic (char **ppsDic,int pos,int *pnPal)                     */
/*      AJUSTA EL DICCIONARIO                                            */
/*                                                                       */
/* Descripcion: Ajusta el diccionario para que no haya huecos entre      */
/*              palabras.                                                */
/*                                                                       */
/* Argumentos: char **ppsDic: el diccionario (vector de palabras)        */
/*             int *pnPal: numero de palabras cargadas                   */
/*             int pos: posicion de la palabra en el diccionario         */                                              
/*                                                                       */
/* Devuelve: el diccionario ajustado y *pnPal actualizado                */
/*                                                                       */
/*-----------------------------------------------------------------------*/

void AjustaDic (char **ppsDic,int pos,int *pnPal);

/*-----------------------------------------------------------------------*/
/* void MenuBorraRep (char **ppsDic,int *pnPal)                          */
/*      BORRA PALABRAS REPETIDAS                                         */
/*                                                                       */
/* Descripcion: Ordena el diccionario, elimina las palabras repetidas y  */
/*              ajusta de nuevo el diccionario.                          */
/*                                                                       */
/* Argumentos: char **ppsDic: el diccionario (vector de palabras)        */
/*             int *pnPal: numero de palabras cargadas                   */
/*                                                                       */
/* Devuelve: el diccionario y *pnPal actualizados                        */
/*                                                                       */
/*-----------------------------------------------------------------------*/

void MenuBorraRep(char **ppsDic,int *pnPal);

#endif
